summaryrefslogtreecommitdiffstats
path: root/chrome/views/window.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/views/window.h')
-rw-r--r--chrome/views/window.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/views/window.h b/chrome/views/window.h
index fcf3e49..cfb0b88 100644
--- a/chrome/views/window.h
+++ b/chrome/views/window.h
@@ -5,7 +5,7 @@
#ifndef CHROME_VIEWS_WINDOW_H__
#define CHROME_VIEWS_WINDOW_H__
-#include "chrome/views/hwnd_view_container.h"
+#include "chrome/views/container_win.h"
namespace gfx {
class Size;
@@ -22,15 +22,15 @@ class Client;
class NonClientView;
class WindowDelegate;
-////////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////////////////////////////////////////////////
//
// Window
//
// A Window is a HWNDViewContainer that has a caption and a border. The frame
// is rendered by the operating system.
//
-////////////////////////////////////////////////////////////////////////////////
-class Window : public HWNDViewContainer {
+///////////////////////////////////////////////////////////////////////////////
+class Window : public ContainerWin {
public:
virtual ~Window();
@@ -156,7 +156,7 @@ class Window : public HWNDViewContainer {
// Shows the system menu at the specified screen point.
void RunSystemMenu(const CPoint& point);
// Overridden from HWNDViewContainer:
virtual void OnActivate(UINT action, BOOL minimized, HWND window);
virtual LRESULT OnAppCommand(HWND window, short app_command, WORD device,
int keystate);
@@ -22,15 +22,15 @@ class Client;
// Window
//
-// A Window is a HWNDViewContainer that has a caption and a border. The frame
-// is rendered by the operating system.
+// A Window is a ContainerWin that has a caption and a border. The frame is
+// rendered by the operating system.
//
@@ -156,7 +156,7 @@ class Window : public HWNDViewContainer {
// Shows the system menu at the specified screen point.
void RunSystemMenu(const CPoint& point);
- // Overridden from HWNDViewContainer:
+ // Overridden from ContainerWin:
virtual void OnActivate(UINT action, BOOL minimized, HWND window);
virtual LRESULT OnAppCommand(HWND window, short app_command, WORD device,